1.  Lipsum

    *   Ichi
    *   Ni
    *   San

2.  Lorem {image-inline file-path="http://placehold.it/350x150" caption="Placeholder image" source="https://placehold.it/" hover-text="This is hover text"}

3.  Ipsem
